@@ -93,9 +93,6 @@ class StickProtocol():
         if preKey:
             PKB["preKey"] = preKey.public
             PKB["preKeyId"] = preKey.keyId
-        else:
-            PKB["preKey"] = None
-            PKB["preKeyId"] = None
         if not isSticky:
             preKey.delete()
         elif preKey:
@@ -141,9 +138,6 @@ class StickProtocol():
                 PKB["preKeyId"] = preKey.keyId
                 preKey.used = True
                 preKey.save()
-            else:
-                PKB["preKey"] = None
-                PKB["preKeyId"] = None
             bundles[id] = PKB
         for id in toBeRemoved:
             users_id.remove(id)
@@ -377,8 +371,9 @@ class StickProtocol():
         """
         decryptingSenderKey = DecryptingSenderKey.objects.create(key=data['key'],
                                                                  stickId=data['stickId'], ofUser=user)
-        preKey = PreKey.objects.get(keyId=data['preKeyId'], user__id=data['forUser'])
-        decryptingSenderKey.preKey = preKey
+        if 'preKeyId' in data:
+            preKey = PreKey.objects.get(keyId=data['preKeyId'], user__id=data['forUser'])
+            decryptingSenderKey.preKey = preKey
         forUser = self.User.objects.get(id=data['forUser'])
         decryptingSenderKey.forUser = forUser
         decryptingSenderKey.save()
@@ -393,7 +388,9 @@ class StickProtocol():
         keys = data['keys']
         for id in users_id:
             senderKey = keys[id]
-            preKey = PreKey.objects.get(keyId=senderKey['preKeyId'], user__id=id)
+            preKey = None
+            if 'preKeyId' in senderKey:
+                preKey = PreKey.objects.get(keyId=senderKey['preKeyId'], user__id=id)
             identityKey = IdentityKey.objects.get(keyId=senderKey['identityKeyId'], user__id=id)
             if id != user.id:  # Other user? Create a DSK
                 forUser = self.User.objects.get(id=senderKey['forUser'])
